[grilo-plugins/wip/jfelder/theaudiodb-artist-art: 5/6] theaudiodb: Use the correct variable for album



commit 092d9b7deed1e682b3f85618b1b7d24d2ccc0233
Author: Jean Felder <jfelder src gnome org>
Date:   Sun Jul 28 12:45:18 2019 +0200

    theaudiodb: Use the correct variable for album
    
    The variable name is album and not title. Title is never used.

 src/lua-factory/sources/grl-theaudiodb-cover.lua | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/lua-factory/sources/grl-theaudiodb-cover.lua 
b/src/lua-factory/sources/grl-theaudiodb-cover.lua
index 2b3b1293..b7127336 100644
--- a/src/lua-factory/sources/grl-theaudiodb-cover.lua
+++ b/src/lua-factory/sources/grl-theaudiodb-cover.lua
@@ -63,7 +63,7 @@ end
 
 function grl_source_resolve()
   local url, keys
-  local artist, title
+  local artist, album
 
   keys = grl.get_media_keys()
   if not keys or not keys.artist or not keys.album
@@ -72,7 +72,7 @@ function grl_source_resolve()
     return
   end
 
   -- Prepare artist and title strings to the url
   artist = grl.encode(keys.artist)
   album = grl.encode(keys.album)
   url = string.format(THEAUDIODB_SEARCH_ALBUM, theaudiodb.api_key, artist, album)
@@ -72,7 +72,7 @@ function grl_source_resolve()
   end
 
-  -- Prepare artist and title strings to the url
+  -- Prepare artist and album strings to the url
   artist = grl.encode(keys.artist)
   album = grl.encode(keys.album)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]